==> owncloud-app-contacts-2%3A1.4.0.0-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/en_GB.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "Address book name" : "Address book name",
    "Import" : "Import",
    "The selected image is too big (max 1MB)" : "The selected image is too big (max 1MB)",
    "No contacts in here" : "No contacts in here",
    "Name" : "Name",
    "Organization" : "Organisation",
    "Title" : "Title",
    "Add field ..." : "Add field ...",
    "+ New contact" : "+ New contact",
    "No search result for {query}" : "No search result for {query}",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
    "Post office box" : "Post office box",
    "Postal code" : "Postcode",
    "City" : "City",
    "State or province" : "State or province",
    "Country" : "Country",
    "Address" : "Address",
    "(new group)" : "(new group)",
    "Last name" : "Surname",
    "First name" : "First-name",
    "Additional names" : "Middle names",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "All contacts" : "All contacts",
    "Not grouped" : "Not grouped",
    "New contact" : "New contact",
    "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
    "No contacts in file. Only VCard files are allowed." : "No contacts in file. Only VCard files are allowed.",
    "Nickname" : "Nickname",
    "Detailed name" : "Detailed name",
    "Notes" : "Notes",
    "Website" : "Website",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Home",
    "Work" : "Work",
    "Other" : "Other",
    "Groups" : "Groups",
    "Birthday" : "Birthday",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Phone",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Social network" : "Social network",
    "Settings" : "Settings"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-contacts-2%3A1.5.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/contacts/l10n/en_GB.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Contacts",
    "Download" : "Download",
    "Share with users or groups" : "Share with users or groups",
    "Delete" : "Delete",
    "can edit" : "can edit",
    "Address book name" : "Address book name",
    "Import" : "Import",
    "The selected image is too big (max 1MB)" : "The selected image is too big (max 1MB)",
    "No contacts in here" : "No contacts in here",
    "Name" : "Name",
    "Organization" : "Organisation",
    "Title" : "Title",
    "Add field ..." : "Add field ...",
    "No search result for {query}" : "No search result for {query}",
    "_%n contact_::_%n contacts_" : ["%n contact","%n contacts"],
    "Post office box" : "Post office box",
    "Postal code" : "Postcode",
    "City" : "City",
    "State or province" : "State or province",
    "Country" : "Country",
    "Address" : "Address",
    "(new group)" : "(new group)",
    "Last name" : "Surname",
    "First name" : "First-name",
    "Additional names" : "Middle names",
    "Prefix" : "Prefix",
    "Suffix" : "Suffix",
    "All contacts" : "All contacts",
    "Not grouped" : "Not grouped",
    "New contact" : "New contact",
    "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
    "No contacts in file. Only VCard files are allowed." : "No contacts in file. Only VCard files are allowed.",
    "Nickname" : "Nickname",
    "Detailed name" : "Detailed name",
    "Notes" : "Notes",
    "Website" : "Website",
    "Federated Cloud ID" : "Federated Cloud ID",
    "Home" : "Home",
    "Work" : "Work",
    "Other" : "Other",
    "Groups" : "Groups",
    "Birthday" : "Birthday",
    "Anniversary" : "Anniversary",
    "Date of death" : "Date of death",
    "Email" : "Email",
    "Instant messaging" : "Instant messaging",
    "Phone" : "Phone",
    "Mobile" : "Mobile",
    "Fax" : "Fax",
    "Fax home" : "Fax home",
    "Fax work" : "Fax work",
    "Pager" : "Pager",
    "Voice" : "Voice",
    "Social network" : "Social network",
    "Settings" : "Settings"
},
"nplurals=2; plural=(n != 1);");
